@@ -4,13 +4,15 @@
 #' @method predict_survival model_fit
 #' @export predict_survival.model_fit
 #' @export
-predict_survival.model_fit <- function(object,
-                                       new_data,
-                                       eval_time,
-                                       time = deprecated(),
-                                       interval = "none",
-                                       level = 0.95,
-                                       ...) {
+predict_survival.model_fit <- function(
+  object,
+  new_data,
+  eval_time,
+  time = deprecated(),
+  interval = "none",
+  level = 0.95,
+  ...
+) {
   if (lifecycle::is_present(time)) {
     lifecycle::deprecate_warn(
       "1.0.4.9005",
@@ -31,8 +33,9 @@ predict_survival.model_fit <- function(object,
   new_data <- prepare_data(object, new_data)
 
   # preprocess data
-  if (!is.null(object$spec$method$pred$survival$pre))
+  if (!is.null(object$spec$method$pred$survival$pre)) {
     new_data <- object$spec$method$pred$survival$pre(new_data, object)
+  }
 
   # create prediction call
   pred_call <- make_pred_call(object$spec$method$pred$survival)
@@ -40,7 +43,7 @@ predict_survival.model_fit <- function(object,
   res <- eval_tidy(pred_call)
 
   # post-process the predictions
-  if(!is.null(object$spec$method$pred$survival$post)) {
+  if (!is.null(object$spec$method$pred$survival$post)) {
     res <- object$spec$method$pred$survival$post(res, object)
   }
 
@@ -51,5 +54,6 @@ predict_survival.model_fit <- function(object,
 #' @keywords internal
 #' @rdname other_predict
 #' @inheritParams predict_survival.model_fit
-predict_survival <- function (object, ...)
+predict_survival <- function(object, ...) {
   UseMethod("predict_survival")
+}
