@@ -31,12 +31,15 @@ test_that('numeric model', {
   expect_snapshot(num_res <- predict(lm_mod, hpc_bad[1:11, -1]))
   expect_equal(num_res, NULL)
 
-  expect_snapshot(ci_res <- predict(lm_mod, hpc_bad[1:11, -1], type = "conf_int"))
+  expect_snapshot(
+    ci_res <- predict(lm_mod, hpc_bad[1:11, -1], type = "conf_int")
+  )
   expect_equal(ci_res, NULL)
 
-  expect_snapshot(pi_res <- predict(lm_mod, hpc_bad[1:11, -1], type = "pred_int"))
+  expect_snapshot(
+    pi_res <- predict(lm_mod, hpc_bad[1:11, -1], type = "pred_int")
+  )
   expect_equal(pi_res, NULL)
-
 })
 
 # ------------------------------------------------------------------------------
@@ -45,24 +48,38 @@ test_that('classification model', {
   log_reg <-
     logistic_reg() |>
     set_engine("glm") |>
-    fit(Class ~ log(funded_amnt) + int_rate + big_num, data = lending_club, control = ctrl)
+    fit(
+      Class ~ log(funded_amnt) + int_rate + big_num,
+      data = lending_club,
+      control = ctrl
+    )
 
   expect_snapshot(
     cls_res <-
-      predict(log_reg, lending_club |>  dplyr::slice(1:7) |> dplyr::select(-Class))
+      predict(
+        log_reg,
+        lending_club |> dplyr::slice(1:7) |> dplyr::select(-Class)
+      )
   )
   expect_equal(cls_res, NULL)
 
   expect_snapshot(
     prb_res <-
-      predict(log_reg, lending_club |>  dplyr::slice(1:7) |> dplyr::select(-Class), type = "prob")
+      predict(
+        log_reg,
+        lending_club |> dplyr::slice(1:7) |> dplyr::select(-Class),
+        type = "prob"
+      )
   )
   expect_equal(prb_res, NULL)
 
   expect_snapshot(
     ci_res <-
-      predict(log_reg, lending_club |>  dplyr::slice(1:7) |> dplyr::select(-Class), type = "conf_int")
+      predict(
+        log_reg,
+        lending_club |> dplyr::slice(1:7) |> dplyr::select(-Class),
+        type = "conf_int"
+      )
   )
   expect_equal(ci_res, NULL)
 })
-
