@@ -27,7 +27,6 @@ hpc_basic <- linear_reg() |> set_engine("lm")
 # ------------------------------------------------------------------------------
 
 test_that('lm execution', {
-
   expect_no_condition(
     res <- fit(
       hpc_basic,
@@ -108,7 +107,6 @@ test_that('lm execution', {
 })
 
 test_that('glm execution', {
-
   hpc_glm <- linear_reg() |> set_engine("glm")
 
   expect_no_condition(
@@ -158,7 +156,6 @@ test_that('glm execution', {
       control = caught_ctrl
     )
   )
-
 })
 
 
@@ -196,11 +193,10 @@ test_that('lm prediction', {
     control = ctrl
   )
 
-  expect_equal(mv_pred, predict(res_mv, hpc[1:5,]))
+  expect_equal(mv_pred, predict(res_mv, hpc[1:5, ]))
 })
 
 test_that('glm prediction', {
-
   hpc_glm <- linear_reg() |> set_engine("glm")
 
   uni_lm <- glm(compounds ~ input_fields + num_pending + iterations, data = hpc)
@@ -225,46 +221,67 @@ test_that('glm prediction', {
   )
 
   expect_equal(inl_pred, predict(res_form, hpc[1:5, ])$.pred)
-
 })
 
 test_that('lm intervals', {
-  stats_lm <- lm(compounds ~ input_fields + iterations + num_pending,
-                 data = hpc)
-  confidence_lm <- predict(stats_lm, newdata = hpc[1:5, ],
-                           level = 0.93, interval = "confidence")
-  prediction_lm <- predict(stats_lm, newdata = hpc[1:5, ],
-                           level = 0.93, interval = "prediction")
+  stats_lm <- lm(
+    compounds ~ input_fields + iterations + num_pending,
+    data = hpc
+  )
+  confidence_lm <- predict(
+    stats_lm,
+    newdata = hpc[1:5, ],
+    level = 0.93,
+    interval = "confidence"
+  )
+  prediction_lm <- predict(
+    stats_lm,
+    newdata = hpc[1:5, ],
+    level = 0.93,
+    interval = "prediction"
+  )
 
   res_xy <- fit_xy(
-    linear_reg()  |> set_engine("lm"),
+    linear_reg() |> set_engine("lm"),
     x = hpc[, num_pred],
     y = hpc$compounds,
     control = ctrl
   )
 
   confidence_parsnip <-
-    predict(res_xy,
-            new_data = hpc[1:5,],
-            type = "conf_int",
-            level = 0.93)
+    predict(res_xy, new_data = hpc[1:5, ], type = "conf_int", level = 0.93)
 
-  expect_equal(confidence_parsnip$.pred_lower, confidence_lm[, "lwr"], ignore_attr = TRUE)
-  expect_equal(confidence_parsnip$.pred_upper, confidence_lm[, "upr"], ignore_attr = TRUE)
+  expect_equal(
+    confidence_parsnip$.pred_lower,
+    confidence_lm[, "lwr"],
+    ignore_attr = TRUE
+  )
+  expect_equal(
+    confidence_parsnip$.pred_upper,
+    confidence_lm[, "upr"],
+    ignore_attr = TRUE
+  )
 
   prediction_parsnip <-
-    predict(res_xy,
-            new_data = hpc[1:5,],
-            type = "pred_int",
-            level = 0.93)
+    predict(res_xy, new_data = hpc[1:5, ], type = "pred_int", level = 0.93)
 
-  expect_equal(prediction_parsnip$.pred_lower, prediction_lm[, "lwr"], ignore_attr = TRUE)
-  expect_equal(prediction_parsnip$.pred_upper, prediction_lm[, "upr"], ignore_attr = TRUE)
+  expect_equal(
+    prediction_parsnip$.pred_lower,
+    prediction_lm[, "lwr"],
+    ignore_attr = TRUE
+  )
+  expect_equal(
+    prediction_parsnip$.pred_upper,
+    prediction_lm[, "upr"],
+    ignore_attr = TRUE
+  )
 })
 
 test_that('glm intervals', {
-  stats_glm <- glm(compounds ~ input_fields + iterations + num_pending,
-                   data = hpc)
+  stats_glm <- glm(
+    compounds ~ input_fields + iterations + num_pending,
+    data = hpc
+  )
   pred_glm <- predict(stats_glm, newdata = hpc[1:5, ], se.fit = TRUE)
   t_val <- qt(0.035, df = stats_glm$df.residual, lower.tail = FALSE)
   lower_glm <- pred_glm$fit - t_val * pred_glm$se.fit
@@ -274,21 +291,17 @@ test_that('glm intervals', {
   upper_glm <- stats_glm$family$linkinv(upper_glm)
 
   res_xy <- fit_xy(
-    linear_reg()  |> set_engine("glm"),
+    linear_reg() |> set_engine("glm"),
     x = hpc[, num_pred],
     y = hpc$compounds,
     control = ctrl
   )
 
   confidence_parsnip <-
-    predict(res_xy,
-            new_data = hpc[1:5,],
-            type = "conf_int",
-            level = 0.93)
+    predict(res_xy, new_data = hpc[1:5, ], type = "conf_int", level = 0.93)
 
   expect_equal(confidence_parsnip$.pred_lower, lower_glm)
   expect_equal(confidence_parsnip$.pred_upper, upper_glm)
-
 })
 
 
@@ -299,9 +312,7 @@ test_that('newdata error trapping', {
     y = hpc$input_fields,
     control = ctrl
   )
-  expect_snapshot(error = TRUE,
-    predict(res_xy, newdata = hpc[1:3, num_pred])
-  )
+  expect_snapshot(error = TRUE, predict(res_xy, newdata = hpc[1:3, num_pred]))
 })
 
 test_that('show engine', {
@@ -318,17 +329,17 @@ test_that('lm can handle rankdeficient predictions', {
   )
 
   data <- data.frame(
-    y = c(1,2,3,4),
-    x1 = c(1,1,2,3),
-    x2 = c(3,4,5,2),
-    x3 = c(4,2,6,0),
-    x4 = c(2,1,3,0)
+    y = c(1, 2, 3, 4),
+    x1 = c(1, 1, 2, 3),
+    x2 = c(3, 4, 5, 2),
+    x3 = c(4, 2, 6, 0),
+    x4 = c(2, 1, 3, 0)
   )
   data2 <- data.frame(
-    x1 = c(3,2,1,3),
-    x2 = c(3,2,1,4),
-    x3 = c(3,4,5,1),
-    x4 = c(0,0,2,3)
+    x1 = c(3, 2, 1, 3),
+    x2 = c(3, 2, 1, 4),
+    x3 = c(3, 4, 5, 1),
+    x4 = c(0, 0, 2, 3)
   )
 
   expect_snapshot(
@@ -395,7 +406,6 @@ test_that("prevent using a Poisson family", {
 # ------------------------------------------------------------------------------
 
 test_that("tunables", {
-
   expect_snapshot(
     linear_reg() |>
       tunable()
@@ -423,6 +433,4 @@ test_that("tunables", {
       set_engine("keras") |>
       tunable()
   )
-
 })
-
