@@ -1,3 +1,4 @@
+skip("waiting for keras3")
 skip_if_not_installed("modeldata")
 
 # ------------------------------------------------------------------------------
@@ -26,7 +27,7 @@ test_that('model fitting', {
     dplyr::sample_n(500) |>
     dplyr::ungroup() |>
     dplyr::select(Class, funded_amnt, int_rate)
-  dat <- dat[order(runif(nrow(dat))),]
+  dat <- dat[order(runif(nrow(dat))), ]
 
   tr_dat <- dat[1:995, ]
   te_dat <- dat[996:1000, ]
@@ -36,11 +37,11 @@ test_that('model fitting', {
   expect_no_condition(
     fit1 <-
       fit_xy(
-      basic_mod,
-      control = ctrl,
-      x = tr_dat[, -1],
-      y = tr_dat$Class
-    )
+        basic_mod,
+        control = ctrl,
+        x = tr_dat[, -1],
+        y = tr_dat$Class
+      )
   )
 
   set_tf_seed(257)
@@ -87,7 +88,6 @@ test_that('model fitting', {
       control = ctrl
     )
   )
-
 })
 
 
@@ -103,7 +103,7 @@ test_that('classification prediction', {
     dplyr::sample_n(500) |>
     dplyr::ungroup() |>
     dplyr::select(Class, funded_amnt, int_rate)
-  dat <- dat[order(runif(nrow(dat))),]
+  dat <- dat[order(runif(nrow(dat))), ]
 
   tr_dat <- dat[1:995, ]
   te_dat <- dat[996:1000, ]
@@ -123,7 +123,9 @@ test_that('classification prediction', {
     predict(lr_fit$fit, as.matrix(te_dat[, -1]))
   keras_pred <-
     tibble::tibble(.pred_class = apply(keras_raw, 1, which.max)) |>
-    dplyr::mutate(.pred_class = factor(lr_fit$lvl[.pred_class], levels = lr_fit$lvl))
+    dplyr::mutate(
+      .pred_class = factor(lr_fit$lvl[.pred_class], levels = lr_fit$lvl)
+    )
 
   parsnip_pred <- predict(lr_fit, te_dat[, -1])
   expect_equal(as.data.frame(keras_pred), as.data.frame(parsnip_pred))
@@ -144,7 +146,6 @@ test_that('classification prediction', {
     mutate(.pred_class = factor(plrfit$lvl[.pred_class], levels = plrfit$lvl))
   parsnip_pred <- predict(plrfit, te_dat[, -1])
   expect_equal(as.data.frame(keras_pred), as.data.frame(parsnip_pred))
-
 })
 
 
@@ -160,7 +161,7 @@ test_that('classification probabilities', {
     dplyr::sample_n(500) |>
     dplyr::ungroup() |>
     dplyr::select(Class, funded_amnt, int_rate)
-  dat <- dat[order(runif(nrow(dat))),]
+  dat <- dat[order(runif(nrow(dat))), ]
 
   tr_dat <- dat[1:995, ]
   te_dat <- dat[996:1000, ]
@@ -200,5 +201,4 @@ test_that('classification probabilities', {
 
   parsnip_pred <- predict(plrfit, te_dat[, -1], type = "prob")
   expect_equal(as.data.frame(keras_pred), as.data.frame(parsnip_pred))
-
 })
