@@ -11,7 +11,6 @@ hpc_nnet <-
 # ------------------------------------------------------------------------------
 
 test_that('nnet execution, classification', {
-
   skip_if_not_installed("nnet")
 
   expect_no_condition(
@@ -45,7 +44,6 @@ test_that('nnet execution, classification', {
 
 
 test_that('nnet classification prediction', {
-
   skip_if_not_installed("nnet")
 
   xy_fit <- fit_xy(
@@ -55,9 +53,16 @@ test_that('nnet classification prediction', {
     control = ctrl
   )
 
-  xy_pred <- predict(extract_fit_engine(xy_fit), newdata = hpc[1:8, num_pred], type = "class")
+  xy_pred <- predict(
+    extract_fit_engine(xy_fit),
+    newdata = hpc[1:8, num_pred],
+    type = "class"
+  )
   xy_pred <- factor(xy_pred, levels = levels(hpc$class))
-  expect_equal(xy_pred, predict(xy_fit, new_data = hpc[1:8, num_pred], type = "class")$.pred_class)
+  expect_equal(
+    xy_pred,
+    predict(xy_fit, new_data = hpc[1:8, num_pred], type = "class")$.pred_class
+  )
 
   form_fit <- fit(
     hpc_nnet,
@@ -66,9 +71,16 @@ test_that('nnet classification prediction', {
     control = ctrl
   )
 
-  form_pred <- predict(extract_fit_engine(form_fit), newdata = hpc[1:8, num_pred], type = "class")
+  form_pred <- predict(
+    extract_fit_engine(form_fit),
+    newdata = hpc[1:8, num_pred],
+    type = "class"
+  )
   form_pred <- factor(form_pred, levels = levels(hpc$class))
-  expect_equal(form_pred, predict(form_fit, new_data = hpc[1:8, num_pred])$.pred_class)
+  expect_equal(
+    form_pred,
+    predict(form_fit, new_data = hpc[1:8, num_pred])$.pred_class
+  )
 })
 
 
@@ -89,9 +101,7 @@ bad_rf_reg <-
 
 # ------------------------------------------------------------------------------
 
-
 test_that('nnet execution, regression', {
-
   skip_if_not_installed("nnet")
 
   expect_no_condition(
@@ -114,9 +124,7 @@ test_that('nnet execution, regression', {
 })
 
 
-
 test_that('nnet regression prediction', {
-
   skip_if_not_installed("nnet")
 
   xy_fit <- fit_xy(
@@ -126,7 +134,7 @@ test_that('nnet regression prediction', {
     control = ctrl
   )
 
-  xy_pred <- predict(extract_fit_engine(xy_fit), newdata = mtcars[1:8, -1])[,1]
+  xy_pred <- predict(extract_fit_engine(xy_fit), newdata = mtcars[1:8, -1])[, 1]
   xy_pred <- unname(xy_pred)
   expect_equal(xy_pred, predict(xy_fit, new_data = mtcars[1:8, -1])$.pred)
 
@@ -137,7 +145,10 @@ test_that('nnet regression prediction', {
     control = ctrl
   )
 
-  form_pred <- predict(extract_fit_engine(form_fit), newdata = mtcars[1:8, -1])[,1]
+  form_pred <- predict(
+    extract_fit_engine(form_fit),
+    newdata = mtcars[1:8, -1]
+  )[, 1]
   form_pred <- unname(form_pred)
   expect_equal(form_pred, predict(form_fit, new_data = mtcars[1:8, -1])$.pred)
 })
@@ -147,7 +158,6 @@ test_that('nnet regression prediction', {
 nn_dat <- read.csv("nnet_test.txt")
 
 test_that('multivariate nnet formula', {
-
   skip_if_not_installed("nnet")
 
   nnet_form <-
@@ -155,11 +165,11 @@ test_that('multivariate nnet formula', {
       mode = "regression",
       hidden_units = 3,
       penalty = 0.01
-    )  |>
+    ) |>
     set_engine("nnet") |>
     parsnip::fit(
       cbind(V1, V2, V3) ~ .,
-      data = nn_dat[-(1:5),]
+      data = nn_dat[-(1:5), ]
     )
 
   expect_false(has_multi_predict(nnet_form))
@@ -178,12 +188,9 @@ test_that('multivariate nnet formula', {
     set_engine("nnet") |>
     parsnip::fit_xy(
       x = nn_dat[-(1:5), -(1:3)],
-      y = nn_dat[-(1:5),   1:3 ]
+      y = nn_dat[-(1:5), 1:3]
     )
   expect_equal(length(extract_fit_engine(nnet_xy)$wts), 24)
   nnet_form_xy <- predict(nnet_xy, new_data = nn_dat[1:5, -(1:3)])
   expect_equal(names(nnet_form_xy), paste0(".pred_", c("V1", "V2", "V3")))
 })
-
-
-
